@@ -1,6 +1,5 @@
 """Common functions for CLI scripts"""
 
-import logging
 import logging.config
 import os
 import sys
@@ -8,9 +7,15 @@ import sys
 import click
 
 from jade.common import HPC_CONFIG_FILE
-from jade.enums import Mode
+from jade.enums import Mode, ResourceMonitorType
 from jade.exceptions import UserAbort
-from jade.models import HpcConfig, LocalHpcConfig, SubmitterParams, get_model_defaults
+from jade.models import (
+    HpcConfig,
+    LocalHpcConfig,
+    SingularityParams,
+    SubmitterParams,
+    get_model_defaults,
+)
 from jade.utils.utils import load_data
 
 
@@ -34,6 +39,12 @@ def handle_enum_input(_, param, value):
         raise click.BadParameter(str(err))
 
 
+def _handle_resource_monitor_type(_, __, value):
+    if value is None:
+        return None
+    return ResourceMonitorType(value)
+
+
 def _handle_simulation_scripts(ctx, _, value):
     if not os.path.exists(value):
         logger.info("Creating %s...", value)
@@ -127,10 +138,24 @@ COMMON_SUBMITTER_OPTIONS = (
     click.option(
         "-r",
         "--resource-monitor-interval",
-        default=SUBMITTER_PARAMS_DEFAULTS["resource_monitor_interval"],
+        default=None,
         type=int,
         show_default=True,
-        help="Interval in seconds on which to collect resource stats. Default is None.",
+        help="Interval in seconds on which to collect resource stats. Default is 1 second if "
+        "--resource-monitor-type is 'aggregation' or 'periodic'.",
+    ),
+    click.option(
+        "-R",
+        "--resource-monitor-type",
+        default=None,
+        type=click.Choice([x.value for x in ResourceMonitorType]),
+        help="Type of resource monitoring to perform. Default is 'aggregation' unless "
+        "--resource-monitor-interval is specified. In order to maintain backwards compatibility "
+        "that changes the default to 'periodic'. "
+        "'aggregation' will keep average/min/max stats in memory and generate a summary report "
+        "at the end. 'periodic' will record stats to files at the specified interval. "
+        "It will generate a summary report as well as interactive HTML plots.",
+        callback=_handle_resource_monitor_type,
     ),
     click.option(
         "-q",
@@ -148,6 +173,20 @@ COMMON_SUBMITTER_OPTIONS = (
         show_default=True,
         help="Generate reports after execution.",
     ),
+    click.option(
+        "-S",
+        "--enable-singularity",
+        is_flag=True,
+        default=False,
+        show_default=True,
+        help="Add Singularity parameters and set the config to run in a container.",
+    ),
+    click.option(
+        "-C",
+        "--container",
+        type=click.Path(exists=True),
+        help="Path to container",
+    ),
     click.option(
         "-t",
         "--time-based-batching",
@@ -204,9 +243,12 @@ def make_submitter_params(
     max_nodes=None,
     poll_interval=None,
     resource_monitor_interval=None,
+    resource_monitor_type=None,
     num_processes=None,
     verbose=None,
     reports=None,
+    enable_singularity=None,
+    container=None,
     try_add_blocked_jobs=None,
     time_based_batching=None,
     node_setup_script=None,
@@ -220,13 +262,14 @@ def make_submitter_params(
         if not os.path.exists(hpc_config):
             print(
                 f"{hpc_config} does not exist. Generate it with 'jade config hpc' "
-                "or run in local mode with '-l'"
+                "or run in local mode with '-l'",
+                file=sys.stderr,
             )
             sys.exit(1)
         hpc_config = HpcConfig(**load_data(hpc_config))
 
     if local and dry_run:
-        print("Dry run is not allowed in local mode.")
+        print("Dry run is not allowed in local mode.", file=sys.stderr)
         sys.exit(1)
 
     if (
@@ -235,13 +278,35 @@ def make_submitter_params(
     ):
         # This doesn't catch the case where the user passes --per-node-batch-size=default, but
         # I don't see that click provides a way to detect that condition.
-        print("Error: --per-node-batch-size and --time-based-batching are mutually exclusive")
+        print(
+            "Error: --per-node-batch-size and --time-based-batching are mutually exclusive",
+            file=sys.stderr,
+        )
         sys.exit(1)
 
     if time_based_batching and num_processes is None:
-        print("Error: num_processes must be set with time-based batching")
+        print("Error: num_processes must be set with time-based batching", file=sys.stderr)
         sys.exit(1)
 
+    # We added resource_monitor_type after resource_monitor_interval. The following logic
+    # maintains backwards compatibility with user settings.
+    default_monitor_interval = SUBMITTER_PARAMS_DEFAULTS["resource_monitor_interval"]
+    if resource_monitor_interval is not None and resource_monitor_type is not None:
+        pass
+    elif resource_monitor_interval is None and resource_monitor_type is None:
+        resource_monitor_type = ResourceMonitorType.AGGREGATION
+        resource_monitor_interval = default_monitor_interval
+    elif resource_monitor_interval is not None and resource_monitor_type is None:
+        resource_monitor_type = ResourceMonitorType.PERIODIC
+    elif resource_monitor_interval is None and resource_monitor_type is not None:
+        resource_monitor_interval = default_monitor_interval
+    else:
+        assert False, f"interval={resource_monitor_interval} type={resource_monitor_type}"
+
+    if enable_singularity:
+        singularity_params = SingularityParams(enabled=True, container=container)
+    else:
+        singularity_params = None
     return SubmitterParams(
         generate_reports=reports,
         hpc_config=hpc_config,
@@ -253,6 +318,8 @@ def make_submitter_params(
         node_shutdown_script=node_shutdown_script,
         poll_interval=poll_interval,
         resource_monitor_interval=resource_monitor_interval,
+        resource_monitor_type=resource_monitor_type,
+        singularity_params=singularity_params,
         time_based_batching=time_based_batching,
         try_add_blocked_jobs=try_add_blocked_jobs,
         verbose=verbose,
