@@ -56,9 +56,12 @@ def submit_jobs(
     output=None,
     poll_interval=None,
     resource_monitor_interval=None,
+    resource_monitor_type=None,
     num_processes=None,
     verbose=None,
     reports=None,
+    enable_singularity=None,
+    container=None,
     try_add_blocked_jobs=None,
     time_based_batching=None,
     node_setup_script=None,
@@ -70,7 +73,10 @@ def submit_jobs(
         if force:
             shutil.rmtree(output)
         else:
-            print(f"{output} already exists. Delete it or use '--force' to overwrite.")
+            print(
+                f"{output} already exists. Delete it or use '--force' to overwrite.",
+                file=sys.stderr,
+            )
             sys.exit(1)
 
     if submitter_params is not None:
@@ -84,9 +90,12 @@ def submit_jobs(
             max_nodes=max_nodes,
             poll_interval=poll_interval,
             resource_monitor_interval=resource_monitor_interval,
+            resource_monitor_type=resource_monitor_type,
             num_processes=num_processes,
             verbose=verbose,
             reports=reports,
+            enable_singularity=enable_singularity,
+            container=container,
             try_add_blocked_jobs=try_add_blocked_jobs,
             time_based_batching=time_based_batching,
             node_setup_script=node_setup_script,
@@ -94,7 +103,7 @@ def submit_jobs(
         )
 
     if params.time_based_batching and params.num_processes is None:
-        print("Error: num_processes must be set with time-based batching")
+        print("Error: num_processes must be set with time-based batching", file=sys.stderr)
         sys.exit(1)
 
     os.makedirs(output)
