@@ -17,6 +17,7 @@ from jade.events import (
     EVENT_NAME_HPC_JOB_ASSIGNED,
     EVENT_NAME_HPC_JOB_STATE_CHANGE,
 )
+from jade.exceptions import InvalidConfiguration
 from jade.hpc.common import HpcJobStatus, HpcType
 from jade.hpc.hpc_manager import HpcManager
 from jade.jobs.async_job_interface import AsyncJobInterface
@@ -60,6 +61,9 @@ class HpcSubmitter:
 
     def _create_run_script(self, config_file, filename, submission_group):
         text = ["#!/bin/bash"]
+        sing_params = submission_group.submitter_params.singularity_params
+        if sing_params and sing_params.enabled:
+            text += sing_params.setup_commands.split("\n")
         command = f"jade-internal run-jobs {config_file} " f"--output={self._output}"
         if submission_group.submitter_params.num_processes is not None:
             command += f" --num-processes={submission_group.submitter_params.num_processes}"
@@ -67,7 +71,7 @@ class HpcSubmitter:
             command += " --verbose"
 
         text.append(command)
-        create_script(filename, "\n".join(text))
+        create_script(filename, "\n".join(text) + "\n")
 
     def _make_async_submitter(self, jobs, submission_group, dry_run=False):
         config = copy.copy(self._base_config)
@@ -123,7 +127,10 @@ class HpcSubmitter:
         completed_job_names, canceled_jobs = self._update_completed_jobs()
 
         lock_file = Path(self._output) / self.LOCK_FILENAME
-        assert not lock_file.exists(), lock_file
+        if lock_file.exists():
+            raise Exception(
+                f"{lock_file} exists. A previous submitter crashed in an unknown state."
+            )
         lock_file.touch()
 
         # Start submitting jobs. If any unexpected exception prevents us from updating the
@@ -409,7 +416,7 @@ class AsyncHpcSubmitter(AsyncJobInterface):
     ):
         self._mgr = hpc_manager
         self._status_collector = status_collector
-        self._run_script = run_script
+        self._run_script = Path(run_script) if run_script else None
         self._submission_group = submission_group
         self._job_id = job_id
         self._output = output
@@ -485,10 +492,15 @@ class AsyncHpcSubmitter(AsyncJobInterface):
 
     def run(self):
         assert self._submission_group is not None
+        sing_params = self._submission_group.submitter_params.singularity_params
+        if sing_params and sing_params.enabled:
+            script = self._make_singularity_command()
+        else:
+            script = self._run_script
         job_id, result = self._mgr.submit(
             self._output,
             self._name,
-            self._run_script,
+            str(script),
             self._submission_group.name,
             dry_run=self._dry_run,
         )
@@ -520,6 +532,19 @@ class AsyncHpcSubmitter(AsyncJobInterface):
     def set_blocking_jobs(self, jobs):
         assert False
 
+    def _make_singularity_command(self):
+        params = self._submission_group.submitter_params.singularity_params
+        if not params.run_command:
+            raise InvalidConfiguration("Singularity command cannot be empty.")
+        container_path = Path(params.container)
+        cmd = f"{params.run_command} {container_path} {self._run_script}"
+        sing_script = self._run_script.parent / self._run_script.name.replace(
+            "run", "singularity", 1
+        )
+        text = "#!/bin/bash\n" + params.load_command + "\n" + cmd + "\n"
+        create_script(str(sing_script), text)
+        return sing_script
+
 
 class HpcStatusCollector:
     """Collects status for all user jobs."""
