@@ -50,6 +50,8 @@ class SlurmManager(HpcManagerInterface):
         # Transient failures could be costly. Retry for up to one minute.
         ret = run_command(cmd, output, num_retries=6, retry_delay_s=10)
         if ret != 0:
+            # TODO: Enhance run_command to not retry on known error messages.
+            # There is no need to retry in this case.
             if "Invalid job id specified" in output["stderr"]:
                 return HpcJobInfo("", "", HpcJobStatus.NONE)
 
@@ -140,6 +142,9 @@ class SlurmManager(HpcManagerInterface):
     def get_config(self):
         return self._config
 
+    def get_current_job_id(self):
+        return os.environ["SLURM_JOB_ID"]
+
     @staticmethod
     def _get_stripe_count(output):
         regex = re.compile(r"stripe_count:\s+(\d+)")
@@ -173,7 +178,7 @@ class SlurmManager(HpcManagerInterface):
 
     def create_submission_script(self, name, script, filename, path):
         text = self._create_submission_script_text(name, script, path)
-        utils.create_script(filename, "\n".join(text))
+        utils.create_script(filename, "\n".join(text) + "\n")
 
     def _create_submission_script_text(self, name, script, path):
         lines = [
